@@ -3,7 +3,7 @@
  *
  * Tests for class related functions for the libsysfs testsuite
  *
- * Copyright (C) IBM Corp. 2004
+ * Copyright (C) IBM Corp. 2004-2005
  *
  *      This program is free software; you can redistribute it and/or modify it
  *      under the terms of the GNU General Public License as published by the
@@ -31,8 +31,6 @@
  * 	(const char *classname, const char *name);
  * extern struct sysfs_device *sysfs_get_classdev_device
  * 				(struct sysfs_class_device *clsdev);
- * extern struct sysfs_driver *sysfs_get_classdev_driver
- * 				(struct sysfs_class_device *clsdev);
  * extern struct sysfs_class_device *sysfs_get_classdev_parent
  *				(struct sysfs_class_device *clsdev);
  * extern void sysfs_close_class(struct sysfs_class *cls);
@@ -42,13 +40,8 @@
  * 			(struct sysfs_class *cls, char *name);
  * extern struct dlist *sysfs_get_classdev_attributes
  * 				(struct sysfs_class_device *cdev);
- * extern struct dlist *sysfs_refresh_classdev_attributes
- * 				(struct sysfs_class_device *cdev);
  * extern struct sysfs_attribute *sysfs_get_classdev_attr
  * 	(struct sysfs_class_device *clsdev, const char *name);
- * extern struct sysfs_attribute *sysfs_open_classdev_attr
- * 			(const char *classname,
- * 			const char *dev, const char *attrib);
  *****************************************************************************
  */
 
@@ -313,72 +306,6 @@ int test_sysfs_get_classdev_device(int flag)
 	return 0;
 }
 
-/**
- * extern struct sysfs_driver *sysfs_get_classdev_driver
- * 				(struct sysfs_class_device *clsdev);
- *
- * flag:
- * 	0:	clsdev -> valid
- * 	1:	clsdev -> NULL
- */
-int test_sysfs_get_classdev_driver(int flag)
-{
-	struct sysfs_class_device *clsdev = NULL;
-	struct sysfs_driver *drv = NULL;
-	char *path = NULL;
-
-	switch(flag) {
-	case 0:
-		path = val_class_dev_path;
-		clsdev = sysfs_open_class_device_path(path);
-		if (clsdev == NULL) {
-			dbg_print("%s: failed opening class device at %s\n",
-					__FUNCTION__, path);
-			return 0;
-		}
-		break;
-	case 1:
-		clsdev = NULL;
-		break;
-	default:
-		return -1;
-
-	}
-	drv = sysfs_get_classdev_driver(clsdev);
-
-	switch (flag) {
-	case 0:
-		if (drv == NULL) {
-			if (errno == 0)
-				dbg_print("%s: Class device at %s does not have a driver symlink\n",
-						__FUNCTION__, path);
-			else
-				dbg_print("%s: FAILED with flag = %d errno = %d\n",
-						__FUNCTION__, flag, errno);
-		} else {
-			dbg_print("%s: SUCCEEDED with flag = %d\n\n",
-						__FUNCTION__, flag);
-			show_driver(drv);
-			dbg_print("\n");
-		}
-		break;
-	case 1:
-		if (drv != NULL)
-			dbg_print("%s: FAILED with flag = %d errno = %d\n",
-						__FUNCTION__, flag, errno);
-		else
-			dbg_print("%s: SUCCEEDED with flag = %d\n",
-						__FUNCTION__, flag);
-		break;
-	default:
-		break;
-	}
-	if (clsdev != NULL)
-		sysfs_close_class_device(clsdev);
-
-	return 0;
-}
-
 /**
  * extern struct sysfs_class_device *sysfs_get_classdev_parent
  *				(struct sysfs_class_device *clsdev);
@@ -563,7 +490,6 @@ int test_sysfs_get_class_devices(int flag)
 		break;
 	default:
 		return -1;
-
 	}
 	list = sysfs_get_class_devices(cls);
 
@@ -762,71 +688,6 @@ int test_sysfs_get_classdev_attributes(int flag)
 	return 0;
 }
 
-/**
- * extern struct dlist *sysfs_refresh_classdev_attributes
- * 				(struct sysfs_class_device *cdev);
- *
- * flag:
- * 	0:	cdev -> valid
- * 	1:	cdev -> NULL
- */
-int test_sysfs_refresh_classdev_attributes(int flag)
-{
-	struct dlist *list = NULL;
-	struct sysfs_class_device *cdev = NULL;
-	char *path = NULL;
-
-	switch (flag) {
-	case 0:
-		path = val_class_dev_path;
-		cdev = sysfs_open_class_device_path(path);
-		if (cdev == NULL) {
-			dbg_print("%s: failed opening class device at %s\n",
-					__FUNCTION__, path);
-			return 0;
-		}
-		break;
-	case 1:
-		cdev = NULL;
-		break;
-	default:
-		return -1;
-	}
-	list = sysfs_refresh_classdev_attributes(cdev);
-
-	switch (flag) {
-	case 0:
-		if (list == NULL) {
-			if (errno == 0)
-				dbg_print("%s: Class device at %s does not export attributes\n",
-						__FUNCTION__, path);
-			else
-				dbg_print("%s: FAILED with flag = %d errno = %d\n",
-						__FUNCTION__, flag, errno);
-		} else {
-			dbg_print("%s: SUCCEEDED with flag = %d\n\n",
-						__FUNCTION__, flag);
-			show_attribute_list(list);
-			dbg_print("\n");
-		}
-		break;
-	case 1:
-		if (list != NULL)
-			dbg_print("%s: FAILED with flag = %d errno = %d\n",
-						__FUNCTION__, flag, errno);
-		else
-			dbg_print("%s: SUCCEEDED with flag = %d\n",
-						__FUNCTION__, flag);
-	default:
-		break;
-	}
-
-	if (cdev != NULL)
-		sysfs_close_class_device(cdev);
-
-	return 0;
-}
-
 /**
  * extern struct sysfs_attribute *sysfs_get_classdev_attr
  * 	(struct sysfs_class_device *clsdev, const char *name);
@@ -936,223 +797,3 @@ int test_sysfs_get_classdev_attr(int flag)
 
 	return 0;
 }
-
-/**
- * extern struct sysfs_attribute *sysfs_open_classdev_attr
- * 			(const char *classname,
- * 			const char *dev,
- * 			const char *attrib);
- * flag:
- * 	0:	classname -> valid, dev -> valid, attrib -> valid
- * 	1:	classname -> valid, dev -> valid, attrib -> invalid
- * 	2:	classname -> valid, dev -> valid, attrib -> NULL
- * 	3:	classname -> valid, dev -> invalid, attrib -> valid
- * 	4:	classname -> valid, dev -> invalid, attrib -> invalid
- * 	5:	classname -> valid, dev -> invalid, attrib -> NULL
- * 	6:	classname -> valid, dev -> NULL , attrib -> valid
- * 	7:	classname -> valid, dev -> NULL , attrib -> invalid
- * 	8:	classname -> valid, dev -> NULL , attrib -> NULL
- * 	9:	classname -> invalid, dev -> valid, attrib -> valid
- * 	10:	classname -> invalid, dev -> valid, attrib -> invalid
- * 	11:	classname -> invalid, dev -> valid, attrib -> NULL
- * 	12:	classname -> invalid, dev -> invalid, attrib -> valid
- * 	13:	classname -> invalid, dev -> invalid, attrib -> invalid
- * 	14:	classname -> invalid, dev -> invalid, attrib -> NULL
- * 	15:	classname -> invalid, dev -> NULL , attrib -> valid
- * 	16:	classname -> invalid, dev -> NULL , attrib -> invalid
- * 	17:	classname -> invalid, dev -> NULL , attrib -> NULL
- * 	18:	classname -> NULL, dev -> valid, attrib -> valid
- * 	19:	classname -> NULL, dev -> valid, attrib -> invalid
- * 	20:	classname -> NULL, dev -> valid, attrib -> NULL
- * 	21:	classname -> NULL, dev -> invalid, attrib -> valid
- * 	22:	classname -> NULL, dev -> invalid, attrib -> invalid
- * 	23:	classname -> NULL, dev -> invalid, attrib -> NULL
- * 	24:	classname -> NULL, dev -> NULL , attrib -> valid
- * 	25	classname -> NULL, dev -> NULL , attrib -> invalid
- * 	26:	classname -> NULL, dev -> NULL , attrib -> NULL
- */
-int  test_sysfs_open_classdev_attr(int flag)
-{
-	struct sysfs_attribute *attr = NULL;
-	char *classname = NULL;
-	char *dev = NULL;
-	char *attrib = NULL;
-
-	switch (flag) {
-	case 0:
-		classname = val_class;
-		dev = val_class_dev;
-		attrib = val_class_dev_attr;
-		break;
-	case 1:
-		classname = val_class;
-		dev = val_class_dev;
-		attrib = inval_name;
-		break;
-	case 2:
-		classname = val_class;
-		dev = val_class_dev;
-		attrib = NULL;
-		break;
-	case 3:
-		classname = val_class;
-		dev= inval_name;
-		attrib = val_class_dev_attr;
-		break;
-	case 4:
-		classname = val_class;
-		dev= inval_name;
-		attrib = inval_name;
-		break;
-	case 5:
-		classname = val_class;
-		dev= inval_name;
-		attrib = NULL;
-		break;
-	case 6:
-		classname = val_class;
-		dev = NULL;
-		attrib = val_class_dev_attr;
-		break;
-	case 7:
-		classname = val_class;
-		dev = NULL;
-		attrib = inval_name;
-		break;
-	case 8:
-		classname = val_class;
-		dev = NULL;
-		attrib = NULL;
-		break;
-	case 9:
-		classname = inval_name;
-		dev = val_class_dev;
-		attrib = val_class_dev_attr;
-		break;
-	case 10:
-		classname = inval_name;
-		dev = val_class_dev;
-		attrib = inval_name;
-		break;
-	case 11:
-		classname = inval_name;
-		dev = val_class_dev;
-		attrib = NULL;
-		break;
-	case 12:
-		classname = inval_name;
-		dev= inval_name;
-		attrib = val_class_dev_attr;
-		break;
-	case 13:
-		classname = inval_name;
-		dev= inval_name;
-		attrib = inval_name;
-		break;
-	case 14:
-		classname = inval_name;
-		dev= inval_name;
-		attrib = NULL;
-		break;
-	case 15:
-		classname = inval_name;
-		dev = NULL;
-		attrib = val_class_dev_attr;
-		break;
-	case 16:
-		classname = inval_name;
-		dev = NULL;
-		attrib = inval_name;
-		break;
-	case 17:
-		classname = inval_name;
-		dev = NULL;
-		attrib = NULL;
-		break;
-	case 18:
-		classname = NULL;
-		dev = val_class_dev;
-		attrib = val_class_dev_attr;
-		break;
-	case 19:
-		classname = NULL;
-		dev = val_class_dev;
-		attrib = inval_name;
-		break;
-	case 20:
-		classname = NULL;
-		dev = val_class_dev;
-		attrib = NULL;
-		break;
-	case 21:
-		classname = NULL;
-		dev= inval_name;
-		attrib = val_class_dev_attr;
-		break;
-	case 22:
-		classname = NULL;
-		dev= inval_name;
-		attrib = inval_name;
-		break;
-	case 23:
-		classname = NULL;
-		dev= inval_name;
-		attrib = NULL;
-		break;
-	case 24:
-		classname = NULL;
-		dev = NULL;
-		attrib = val_class_dev_attr;
-		break;
-	case 25:
-		classname = NULL;
-		dev = NULL;
-		attrib = inval_name;
-		break;
-	case 27:
-		classname = NULL;
-		dev = NULL;
-		attrib = NULL;
-		break;
-	default:
-		return -1;
-	}
-	attr = sysfs_open_classdev_attr(classname, dev, attrib);
-
-	switch (flag) {
-	case 0:
-		if (attr == NULL) {
-			if (errno == EACCES)
-				dbg_print("%s: attribute %s does not support READ\n",
-						__FUNCTION__, attrib);
-			else if (errno == ENOENT)
-				dbg_print("%s: attribute %s not defined for class device %s\n",
-						__FUNCTION__, attrib, dev);
-			else if (errno == 0)
-				dbg_print("%s: class device %s does not export attributes\n",
-						__FUNCTION__, dev);
-			else
-				dbg_print("%s: FAILED with flag = %d errno = %d\n",
-						__FUNCTION__, flag, errno);
-		} else {
-			dbg_print("%s: SUCCEEDED with flag = %d\n\n",
-						__FUNCTION__, flag);
-			show_attribute(attr);
-			dbg_print("\n");
-		}
-		break;
-	default:
-		if (attr != NULL)
-			dbg_print("%s: FAILED with flag = %d errno = %d\n",
-						__FUNCTION__, flag, errno);
-		else
-			dbg_print("%s: SUCCEEDED with flag = %d\n",
-						__FUNCTION__, flag);
-		break;
-
-	}
-	if (attr != NULL)
-		sysfs_close_attribute(attr);
-
-	return 0;
-}
